#@TYPE: Platform template
#@NAME: stm32mp-t1000-common
#@DESCRIPTION: Common machine configuration for t1000 hardware platform
#@NEEDED_BSPLAYERS: meta-st-stm32mp

PREFERRED_PROVIDER_virtual/kernel = "linux-stm32mp"
PREFERRED_VERSION_linux-stm32mp ?= "4.14"
# PREFERRED_PROVIDER_virtual/bootloader doesn't exist because multiple
# u-boot loaders can be built (see meta-st-stm32mp/recipes-bsp/u-boot/u-boot-stm32mp.inc

include conf/machine/include/st-machine-common-stm32mp.inc

# Define specific common layer name
MACHINEOVERRIDES =. "stm32mp-t1000:"

# =========================================================================
# Machine features
# =========================================================================
MACHINE_FEATURES += "${@'gpu' if d.getVar('ACCEPT_EULA_'+d.getVar('MACHINE', True), True) == '1' else ''}"


# =========================================================================
# Machine settings
# =========================================================================
# Default machine feature
# See ST definition
#MACHINE_FEATURES = "usbhost usbgadget alsa screen ext2"

# Default serial consoles (TTYs) to enable using getty
SERIAL_CONSOLES = "115200;ttyS3"
SERIAL_CONSOLE = "115200 ttyS3"

# We have no soundcard (yet). So remove configuration and current settings file
# from OpenST for alsa
MACHINE_EXTRA_RRECOMMENDS_remove = "alsa-state-stm32mp1"

# What should be built alongside this image
EXTRA_IMAGEDEPENDS += "tf-a-stm32mp"
EXTRA_IMAGEDEPENDS += "u-boot-basic-stm32mp"
EXTRA_IMAGEDEPENDS += "u-boot-trusted-stm32mp"

# =========================================================================
# Chip architecture
# =========================================================================
DEFAULTTUNE = "cortexa7thf-neon-vfpv4"
include conf/machine/include/tune-cortexa7.inc


# =========================================================================
# Kernel
# =========================================================================
# Kernel config
ST_KERNEL_ENTRYPOINT = "0xC0008000"
ST_KERNEL_LOADADDR   = "0xC0008000"


# =========================================================================
# U-Boot
# =========================================================================

UBOOT_CONFIG_FILEPATTERN = "_devicetree_"

# Set u-boot configuration (combination of devicetree and defconfig)
UBOOT_DEVICETREE = ""


# =========================================================================
# Image
# =========================================================================
# Append ubi FSTYPES to default ones
IMAGE_FSTYPES = "tar.xz ext4 stmultiubi"

# Define image to use for extra partitions
STM32MP_BOOTFS_IMAGE = "st-image-bootfs"
STM32MP_USERFS_IMAGE = "st-image-userfs"

# Define extra partition to build
PARTITIONS_IMAGE = "${STM32MP_BOOTFS_IMAGE} ${STM32MP_USERFS_IMAGE}"

# Define image partition size (supposed to be set as max size in image recipe)
# Bootfs partition size 20MB (kernel ~7MB)
BOOTFS_PARTITION_SIZE = "20480"
#Rootfs partition size 512MB
#ROOTFS_PARTITION_SIZE = "524288"
# Rootfs partition size (with Qt)
ROOTFS_PARTITION_SIZE = "786432"
# Userfs partition size 128MB
USERFS_PARTITION_SIZE = "131072"
# Pay attention: QSPI NAND is 512MB on
# Overall size: fsbl1+2 2x256k, ssbl 2M, bootfs 20M, rootfs 512M, userfs 128M

# Define volume list for multivolume UBIFS
STM32MP_UBI_VOLUME += "${STM32MP_BOOTFS_IMAGE}-${DISTRO}-${MACHINE}:${BOOTFS_PARTITION_SIZE}"
STM32MP_UBI_VOLUME += "${IMAGE_LINK_NAME}:${ROOTFS_PARTITION_SIZE}"
STM32MP_UBI_VOLUME += "${STM32MP_USERFS_IMAGE}-${DISTRO}-${MACHINE}:${USERFS_PARTITION_SIZE}"

# Set on machine side the max size for ROOTFS image to apply for default rootfs being built
# On other image partition such settings is directly done in image recipe
IMAGE_ROOTFS_MAXSIZE ?= "${ROOTFS_PARTITION_SIZE}"

# ST Naming rules partitions for UBI format are :
#   nand_<PageSize>_<BlockSize>
#   nor_<BlockSize>
# Like that a same UBI partition can be used for severals NAND/NOR providers

# UBI Args for NAND soldered by default on MB1262
# Micron MT29F8G16ABACAH4
# LEB = BLOCK_SIZE - (2 * page size): 256*1024 - (2*4096)
MKUBIFS_ARGS_nand_4_256 = "--min-io-size 4096 --leb-size 253952 --max-leb-cnt 4096 --space-fixup"
UBINIZE_ARGS_nand_4_256 = "--min-io-size 4096 --peb-size 256KiB"

# Define UBI labels to build
MULTIUBI_BUILD = " nand_4_256 "

# TODO: set correct values for this flash type
# currently mtdinfo reports some weird values (i/o size of 4069)
#
#   root@stmxceet:~# ubiformat /dev/mtd3
#   ubiformat: error!: min. I/O size is 4069, but should be power of 2
#
# -> wait for new kernel
#   root@stmxceet:~# mtdinfo -u /dev/mtd3
#   mtd3
#   Name:                           spi0.1
#   Type:                           nand
#   Eraseblock size:                260416 bytes, 254.3 KiB
#    of eraseblocks:          2048 (533331968 bytes, 508.6 MiB)
#   Minimum input/output unit size: 4069 bytes
#   Sub-page size:                  4069 bytes
#   OOB size:                       256 bytes
#   Character device major/minor:   90:6
#   Bad blocks are allowed:         true
#   Device is writable:             true
#   Default UBI VID header offset:  4069
#   Default UBI data offset:        8138
#   Default UBI LEB size:           252278 bytes, 246.4 KiB
#   Maximum UBI volumes count:      128


# =========================================================================
# flashlayout files for STM32_Programmer (has to fit with image definitions!)
# =========================================================================
#
# Generate flashlayout files
FLASHLAYOUT_PARTITION_ENABLE = "1"

# Define which flashlayout file should be generated
# sdcard   - booting from sdcard
# nor-emmc - bootloader (tf-a, u-boot) is in NOR flash, rootfs etc. is in eMMC
# nor-nand - bootloader (tf-a, u-boot) is in NOR flash, rootfs etc. is in QSPI NAND
FLASHLAYOUT_CONFIG_LABELS = "sdcard nor-emmc nor-nand-4-256"
FLASHLAYOUT_RESTRICTION_TYPES_sdcard = ""
FLASHLAYOUT_RESTRICTION_TYPES_nor-emmc = ""
FLASHLAYOUT_RESTRICTION_TYPES_nor-nand-4-256 = ""

# Define which bootschemes should be generated
# basic   - only for board bringup (DDR calibration)
# trusted - standard configuration
FLASHLAYOUT_BOOTSCHEME_LABELS = "basic trusted"

# -----------------------------------------------------------------------------
# Partition configuration for each partition label
# NOTE: each item can be defined with following priority assignment:
#           1) item_<BOOTSCHEME>_<CONFIG>_<PARTITION>
#           2) item_<BOOTSCHEME>_<CONFIG>
#           3) item_<BOOTSCHEME>_<PARTITION>
#           4) item_<BOOTSCHEME>
#           5) item_<CONFIG>_<PARTITION>
#           6) item_<CONFIG>
#           7) item_<PARTITION>
#           8) Default 'item' to 'none' when not defined
# -----------------------------------------------------------------------------

# -----------------------------------------------------------------------------
# Define common partitions IDs
# -----------------------------------------------------------------------------
# common partition ids
FLASHLAYOUT_PARTITION_ID_fsbl1  = "0x01"
FLASHLAYOUT_PARTITION_ID_fsbl2  = "0x02"
FLASHLAYOUT_PARTITION_ID_ssbl   = "0x03"
FLASHLAYOUT_PARTITION_ID_env    = "0x04"
FLASHLAYOUT_PARTITION_ID_empty  = "0x10"
FLASHLAYOUT_PARTITION_ID_bootfs = "0x11"
FLASHLAYOUT_PARTITION_ID_rootfs = "0x12"
FLASHLAYOUT_PARTITION_ID_userfs = "0x13"


# -----------------------------------------------------------------------------
# Define common partitions types
# -----------------------------------------------------------------------------
# common partition types
FLASHLAYOUT_PARTITION_TYPE                  = "Binary"
FLASHLAYOUT_PARTITION_TYPE_env              = "Empty"
FLASHLAYOUT_PARTITION_TYPE_empty            = "Empty"
FLASHLAYOUT_PARTITION_TYPE_bootfs           = "System"
FLASHLAYOUT_PARTITION_TYPE_rootfs           = "FileSystem"
FLASHLAYOUT_PARTITION_TYPE_userfs           = "FileSystem"


# -----------------------------------------------------------------------------
# Define common partitions contents
# -----------------------------------------------------------------------------
# Set default binaries to flash for each partition

# trusted configuration
FLASHLAYOUT_PARTITION_BIN2LOAD_trusted_fsbl1   = "tf-a.stm32"
FLASHLAYOUT_PARTITION_BIN2LOAD_trusted_fsbl2   = "tf-a.stm32"
FLASHLAYOUT_PARTITION_BIN2LOAD_trusted_ssbl    = "u-boot.stm32"
FLASHLAYOUT_PARTITION_BIN2LOAD_trusted_bootfs  = "${STM32MP_BOOTFS_IMAGE}-${DISTRO}-${MACHINE}.ext4"
FLASHLAYOUT_PARTITION_BIN2LOAD_trusted_rootfs  = "${IMAGE_LINK_NAME}.ext4"
FLASHLAYOUT_PARTITION_BIN2LOAD_trusted_userfs  = "${STM32MP_USERFS_IMAGE}-${DISTRO}-${MACHINE}.ext4"

# basic configuration
FLASHLAYOUT_PARTITION_BIN2LOAD_basic_fsbl1   = "u-boot-spl.stm32"
FLASHLAYOUT_PARTITION_BIN2LOAD_basic_fsbl2   = "u-boot-spl.stm32"
FLASHLAYOUT_PARTITION_BIN2LOAD_basic_ssbl    = "u-boot.img"
FLASHLAYOUT_PARTITION_BIN2LOAD_basic_bootfs  = "none"
FLASHLAYOUT_PARTITION_BIN2LOAD_basic_rootfs = "none"
FLASHLAYOUT_PARTITION_BIN2LOAD_basic_userfs = "none"

# Binaries to boot from RAM (only board bring up)
FLASHLAYOUT_PARTITION_BIN2BOOT_fsbl1 = "tf-a.stm32"
FLASHLAYOUT_PARTITION_BIN2BOOT_fsbl2 = "tf-a.stm32"
FLASHLAYOUT_PARTITION_BIN2BOOT_ssbl = "u-boot.stm32"


# -----------------------------------------------------------------------------
# Define flash layouts
# -----------------------------------------------------------------------------

# sdcard flashlayout
# -----------------------------------------------------------------------------
# fsbl1  on SDMMC1 size 0x00040000 (256k)
# fsbl2  on SDMMC1 size 0x00040000 (256k)
# ssbl   on SDMMC1 size 0x00200000 (2M)
# bootfs on SDMMC1 size 0x01400000 (20M)
# rootfs on SDMMC1 size 0x20000000 (512M)
# userfs on SDMMC1 size rest of device

FLASHLAYOUT_PARTITION_LABELS = "fsbl1 fsbl2 ssbl bootfs rootfs userfs"

# Device SDMMC1
# Fixed offsets in ROM code (cut1 version) for fsbl1 and fsbl2: 0x4400, 0x44400
FLASHLAYOUT_PARTITION_DEVICE_sdcard = "SDMMC1"
FLASHLAYOUT_PARTITION_OFFSET_sdcard_fsbl1  = "0x00004400"
FLASHLAYOUT_PARTITION_OFFSET_sdcard_fsbl2  = "0x00044400"
FLASHLAYOUT_PARTITION_OFFSET_sdcard_ssbl   = "0x00084400"
FLASHLAYOUT_PARTITION_OFFSET_sdcard_bootfs = "0x00284400"
FLASHLAYOUT_PARTITION_OFFSET_sdcard_rootfs = "0x01684400"
FLASHLAYOUT_PARTITION_OFFSET_sdcard_userfs = "0x21684400"


# nor-emmc flashlayout
# -----------------------------------------------------------------------------
# fsbl1  on SPI1   size 0x40000 (256k)
# fsbl2  on SPI1   size 0x40000 (256k)
# ssbl   on SPI1   size 0x100000 (1M)
# empty  on SPI1   size rest of device
# bootfs on SDMMC2 size 0x01400000 (20M)
# rootfs on SDMMC2 size 0x20000000 (512M)
# userfs on SDMMC2 size rest of device
# 'empty' partition is a fake partition just to limit ssbl size to 2MBytes

FLASHLAYOUT_PARTITION_LABELS_nor-emmc = "fsbl1 fsbl2 ssbl env empty bootfs rootfs userfs"

# Device SPI1
# Fixed offsets in ROM code for fsbl1 and fsbl2: 0x0, 0x40000
FLASHLAYOUT_PARTITION_DEVICE_nor-emmc_fsbl1  = "SPI1"
FLASHLAYOUT_PARTITION_DEVICE_nor-emmc_fsbl2  = "SPI1"
FLASHLAYOUT_PARTITION_DEVICE_nor-emmc_ssbl   = "SPI1"
FLASHLAYOUT_PARTITION_OFFSET_nor-emmc_fsbl1  = "0x00000000"
FLASHLAYOUT_PARTITION_OFFSET_nor-emmc_fsbl2  = "0x00040000"
FLASHLAYOUT_PARTITION_OFFSET_nor-emmc_ssbl   = "0x00080000"
FLASHLAYOUT_PARTITION_OFFSET_nor-emmc_env    = "0x00180000"
FLASHLAYOUT_PARTITION_OFFSET_nor-emmc_empty  = "0x00190000"

# Device SDMMC2
FLASHLAYOUT_PARTITION_DEVICE_nor-emmc_bootfs = "SDMMC2"
FLASHLAYOUT_PARTITION_DEVICE_nor-emmc_rootfs = "SDMMC2"
FLASHLAYOUT_PARTITION_DEVICE_nor-emmc_userfs = "SDMMC2"
FLASHLAYOUT_PARTITION_OFFSET_nor-emmc_bootfs = "0x00004400"
FLASHLAYOUT_PARTITION_OFFSET_nor-emmc_rootfs = "0x01404400"
FLASHLAYOUT_PARTITION_OFFSET_nor-emmc_userfs = "0x21404400"


# nor-nand-4-256 flashlayout
# -----------------------------------------------------------------------------
# fsbl1  on SPI1   size 0x40000 (256k)
# fsbl2  on SPI1   size 0x40000 (256k)
# ssbl   on SPI1   size 0x100000 (1M)
# empty  on SPI1   size rest of device
# bootfs on FMC    size 0x01400000 (20M)
# rootfs on FMC    size 0x20000000 (392M)
# userfs on FMC    size rest of device (100M)
# 'empty' partition is a fake partition just to limit ssbl size to 2MBytes

FLASHLAYOUT_PARTITION_LABELS_nor-nand-4-256 = "fsbl1 fsbl2 ssbl empty bootfs rootfs userfs"

# Device SPI1
# Fixed offsets in ROM code for fsbl1 and fsbl2: 0x0, 0x40000
FLASHLAYOUT_PARTITION_DEVICE_nor-nand-4-256_fsbl1  = "SPI1"
FLASHLAYOUT_PARTITION_DEVICE_nor-nand-4-256_fsbl2  = "SPI1"
FLASHLAYOUT_PARTITION_DEVICE_nor-nand-4-256_ssbl   = "SPI1"
FLASHLAYOUT_PARTITION_OFFSET_nor-nand-4-256_fsbl1  = "0x00000000"
FLASHLAYOUT_PARTITION_OFFSET_nor-nand-4-256_fsbl2  = "0x00040000"
FLASHLAYOUT_PARTITION_OFFSET_nor-nand-4-256_ssbl   = "0x00080000"
FLASHLAYOUT_PARTITION_OFFSET_nor-nand-4-256_env    = "0x00180000"
FLASHLAYOUT_PARTITION_OFFSET_nor-nand-4-256_empty  = "0x00190000"

# Device FMC1
FLASHLAYOUT_PARTITION_DEVICE_nor-nand-4-256_bootfs = "FMC1"
FLASHLAYOUT_PARTITION_DEVICE_nor-nand-4-256_rootfs = "FMC1"
FLASHLAYOUT_PARTITION_DEVICE_nor-nand-4-256_userfs = "FMC1"
FLASHLAYOUT_PARTITION_OFFSET_nor-nand-4-256_bootfs = "0x00000000"
FLASHLAYOUT_PARTITION_OFFSET_nor-nand-4-256_rootfs = "0x01400000"
FLASHLAYOUT_PARTITION_OFFSET_nor-nand-4-256_userfs = "0x19C00000"

# NAND special settings
FLASHLAYOUT_PARTITION_TYPE_nand-4-256_fsbl1 = "Binary(4)"
FLASHLAYOUT_PARTITION_BIN2LOAD_nand-4-256_bootfs = "${IMAGE_LINK_NAME}_nand_4_256.ubi"
FLASHLAYOUT_PARTITION_BIN2LOAD_nand-4-256_rootfs = "${IMAGE_LINK_NAME}_nand_4_256.ubi"
FLASHLAYOUT_PARTITION_BIN2LOAD_nand-4-256_userfs = "${STM32MP_USERFS_IMAGE}-${DISTRO}-${MACHINE}_nand_4_256.ubi"


# =========================================================================
# Extlinux boot commands
# =========================================================================
# Define boot command lines
#
# The following bootschemes are supported
# - boot from sdcard (BOOTPIN_0,2=1, BOOTPIN_1=0)
# - boot from nor (BOOTPIN_0=1, BOOTPIN_3,2=0)
#   When booting from nor u-boot variable 'boot_targets' select where to find
#   the bootfs with EXTLINUX configuration
#

# Add extlinux definintions for boards
UBOOT_EXTLINUX_TIMEOUT = "20"
UBOOT_EXTLINUX_KERNEL_IMAGE = "/${KERNEL_IMAGETYPE}"


# =========================================================================
# Specific features settings
# =========================================================================
# OPTEE
OPTEE_OS_WITH_PAGER = "n"

