#!/bin/bash

# fetch_files_workdir <DEVTOOL_WORKDIR>

FILELIST="\
	arch/arm/dts/stmxceet-mp157-som.dts \
	arch/arm/dts/stmxceet-mp157-som-spl.dts \
	arch/arm/dts/stmxceet-mp157-som_ddr.h \
	arch/arm/dts/stmxceet-mp157-som_rcc.dtsi \
	arch/arm/dts/stmxceet-mp157-som_pinctrl.dtsi \
	"

red=`tput setaf 1`
green=`tput setaf 2`
yellow=`tput setaf 3`
reset=`tput sgr0`

DEVTOOL_WORKDIR=${1}
COMMAND=${2}

print_usage ()
{
	echo "fetch_files_workdir <DEVTOOL_WORKDIR> [diff]"
}

echo "$1"
if test -z "${DEVTOOL_WORKDIR}"; then
	print_usage
	echo -n $red
	echo "ERROR: No workdir on commandline"
	echo -n $reset
	exit 1
fi
if test ! -d "${DEVTOOL_WORKDIR}"; then
	echo -n $red
	echo "ERROR: Workdir <${DEVTOOL_WORKDIR}> doesn't exist"
	echo -n $reset
	exit 1
fi

# COMMAND configuration
if test ! -z "${COMMAND}"; then
	echo "Command: ${COMMAND}"
fi
do_onlydiff="no"
if test "${COMMAND}" == "diff"; then
	do_onlydiff="yes"
fi

for wdfile in ${FILELIST}; do
	file_differ="no"
	filename=$(basename $wdfile)
	if test ! -e u-boot-stm32mp/${filename}; then
		echo -n $yellow
		echo "new      : $filename"
		echo -n $reset
		file_differ="yes"
	else
		cmp -s ${DEVTOOL_WORKDIR}/${wdfile} u-boot-stm32mp/${filename}
		if test $? != 0; then
			echo -n $red
			echo "differ   : $filename"
			echo -n $reset
			file_differ="yes"
		else
			echo -n $green
			echo "unchanged: $filename"
			echo -n $reset
		fi
	fi
	
	if test ${file_differ} = "yes" -a ${do_onlydiff} != "yes" ; then
	
		echo "Show differences [Y/n]?"
		read show_diff
		if test -z "${show_diff}"; then
			show_diff="Y"
		fi
		if test "${show_diff}" == "Y" -o ${show_diff} == "y"; then
			meld ${DEVTOOL_WORKDIR}/${wdfile} u-boot-stm32mp/${filename}
		fi
				
		echo "Copy files [y/N]?"
		read copy_files
		if test -z "${copy_files}"; then
			copy_files="N"
		fi
		if test "${copy_files}" == "y" -o "${copy_files}" == "y"; then
			cp ${DEVTOOL_WORKDIR}/${wdfile} u-boot-stm32mp/${filename}
		fi
	fi

done

