/*
 * Copyright (C) 2018, STMicroelectronics - All Rights Reserved
 *
 * SPDX-License-Identifier:	GPL-2.0+	BSD-3-Clause
 */

#include <config.h>
#include <common.h>
#include <spl.h>
#include <dm.h>
#include <ram.h>
#include <asm/io.h>
#include <post.h>
#include <power/pmic.h>
#include <power/stpmu1.h>
#include <asm/arch/ddr.h>

void spl_board_init(void)
{
	/* Keep vdd on during the reset cycle */
#if defined(CONFIG_PMIC_STPMU1) && defined(CONFIG_SPL_POWER_SUPPORT)
	struct udevice *dev;
	int ret;

	ret = uclass_get_device_by_driver(UCLASS_PMIC,
					  DM_GET_DRIVER(pmic_stpmu1), &dev);
	if (!ret)
		pmic_clrsetbits(dev,
				STPMU1_MASK_RESET_BUCK,
				STPMU1_MASK_RESET_BUCK3,
				STPMU1_MASK_RESET_BUCK3);

	/* Check if debug is enabled to program PMIC according to the bit */
	if ((readl(TAMP_BOOT_CONTEXT) & TAMP_BOOT_DEBUG_ON) && !ret) {
		printf("Keep debug unit ON\n");

		pmic_clrsetbits(dev, STPMU1_MASK_RESET_BUCK,
				STPMU1_MASK_RESET_BUCK_DBG,
				STPMU1_MASK_RESET_BUCK_DBG);

		pmic_clrsetbits(dev, STPMU1_MASK_RESET_LDOS,
				STPMU1_MASK_RESET_LDOS_DBG,
				STPMU1_MASK_RESET_LDOS_DBG);
	}


	/* Ticket 42582  - [STPMU1]: Software workaround regarding buck
	 *                           converter bug
	 * TEMP => to be removed after PMIC silicon fix
	 */
	if (!ret) {
		printf("STPMU1: BUCK3 and BUCK4 workaround for cut1\n");
		pmic_clrsetbits(dev,
				STPMU1_BUCKX_CTRL_REG(STPMU1_BUCK3),
				STPMU1_BUCK_MODE,
				STPMU1_BUCK_MODE);
		pmic_clrsetbits(dev,
				STPMU1_BUCKX_CTRL_REG(STPMU1_BUCK4),
				STPMU1_BUCK_MODE,
				STPMU1_BUCK_MODE);
	}
#endif
}
