/*
 * Copyright (C) 2015-2017, STMicroelectronics - All Rights Reserved
 *
 * Configuration settings for the STM32MP15x CPU
 *
 * SPDX-License-Identifier:	GPL-2.0+	BSD-3-Clause
 */

#ifndef __CONFIG_H
#define __CONFIG_H
#include <linux/sizes.h>
#include <asm/arch/stm32.h>

#define CONFIG_DISPLAY_BOARDINFO_LATE	/* Calls show_board_info() */
#define CONFIG_MISC_INIT_R

/*
 * Number of clock ticks in 1 sec
 */
#define CONFIG_SYS_HZ				1000
#define CONFIG_SYS_ARCH_TIMER

#ifndef CONFIG_STM32MP1_TRUSTED
/* PSCI support */
#define CONFIG_ARMV7_PSCI_1_0
#define CONFIG_ARMV7_SECURE_BASE		STM32_SYSRAM_BASE
#define CONFIG_ARMV7_SECURE_MAX_SIZE		STM32_SYSRAM_SIZE
#endif

/*
 * malloc() pool size
 */
#define CONFIG_SYS_MALLOC_LEN			SZ_32M

/* possible value for CONFIG_SYS_TEXT_BASE
 * 1- normal use case : UBOOT running in DDR => 0xC0100000
 * 2- sysram: U-Boot load by bootrom, STM32_SYSRAM_BASE = 0x2FFC2500
 * 3- test: ATF in sysram + U-Boot in MCU SRAM = 0x30000000
 */

#if (CONFIG_SYS_TEXT_BASE != 0x2FFC2500) && \
	(CONFIG_SYS_TEXT_BASE != 0x30000000) && \
	(CONFIG_SYS_TEXT_BASE < STM32_DDR_BASE)
#error invalid CONFIG_SYS_TEXT_BASE
#endif

#if (CONFIG_SYS_TEXT_BASE >= STM32_DDR_BASE)
/*
 * Configuration of the external SRAM memory used by U-Boot
 */
#define CONFIG_SYS_SDRAM_BASE			STM32_DDR_BASE
#define CONFIG_SYS_INIT_SP_ADDR			CONFIG_SYS_TEXT_BASE
#else
/*
 * Configuration of the internal SRAM memory used by U-Boot*
 * NB: -4 for CONFIG_SYS_POST_WORD_ADDR
 */
#if (CONFIG_SYS_TEXT_BASE == 0x30000000)
#define CONFIG_SYS_SDRAM_BASE			STM32_MCU_SRAM_BASE
#define CONFIG_SYS_SDRAM_SIZE			STM32_MCU_SRAM_SIZE
#define CONFIG_SYS_INIT_SP_ADDR			(STM32_MCU_SRAM_BASE +\
						 STM32_MCU_SRAM_SIZE - 4)

#else /* remaining case = 0x2FFC2500 */

#define CONFIG_SYS_SDRAM_BASE			STM32_DDR_BASE
#define CONFIG_SYS_SDRAM_SIZE			STM32_DDR_SIZE
#define CONFIG_SYS_INIT_SP_ADDR			(STM32_SYSRAM_BASE +\
						 STM32_SYSRAM_SIZE +\
						 STM32_MCU_SRAM_SIZE - 4)
#endif

#if defined(CONFIG_SYS_DCACHE_OFF) && defined(CONFIG_SYS_ICACHE_OFF)
#error "reserve_mmu() is mandatory for location of INIT_SP_ADDR"
#endif

#endif /*(CONFIG_SYS_TEXT_BASE >= STM32_DDR_BASE)*/

#define CONFIG_NR_DRAM_BANKS	1

#define CONFIG_DISABLE_CONSOLE

/*
 * Console I/O buffer size
 */
#define CONFIG_SYS_CBSIZE			SZ_1K

/*
 * Needed by "loadb"
 */
#define CONFIG_SYS_LOAD_ADDR			STM32_DDR_BASE

/*
 * Env parameters
 */
#define CONFIG_ENV_SIZE				SZ_16K
#define CONFIG_ENV_VARS_UBOOT_RUNTIME_CONFIG

/* Environment in SPI NOR */
#ifdef CONFIG_ENV_IS_IN_SPI_FLASH

#define CONFIG_ENV_OFFSET		(0x18 * SZ_64K)
#define CONFIG_ENV_SECT_SIZE	(SZ_64K)
#define CONFIG_ENV_SPI_BUS		(0)
#define CONFIG_ENV_SPI_CS		(0)
#define CONFIG_ENV_SPI_MODE		(SPI_MODE_0)
#define CONFIG_ENV_SPI_MAX_HZ	(1000000)

#endif

/* ATAGs */
#define CONFIG_CMDLINE_TAG
#define CONFIG_SETUP_MEMORY_TAGS
#define CONFIG_INITRD_TAG

/* Extend size of kernel image for uncompression */
#define CONFIG_SYS_BOOTM_LEN			SZ_64M

/* SPL support */
#ifdef CONFIG_SPL
/* BOOTROM load address */
#define CONFIG_SPL_TEXT_BASE		0x2FFC2500
/* SPL use DDR */
#define CONFIG_SPL_BSS_START_ADDR	0xC0200000
#define CONFIG_SPL_BSS_MAX_SIZE		0x00100000
#define CONFIG_SYS_SPL_MALLOC_START	0xC0300000
#define CONFIG_SYS_SPL_MALLOC_SIZE	0x00100000

/* limit SYSRAM usage to first 128 KB */
#define CONFIG_SPL_MAX_SIZE		0x00020000
#define CONFIG_SPL_STACK		(STM32_SYSRAM_BASE + \
					 STM32_SYSRAM_SIZE)
#endif /* #ifdef CONFIG_SPL */

/* FOR TEST */
#define CONFIG_SYS_ALT_MEMTEST /* Much more complex memory test */
/* TEMP: reserved 1MB at base for scripts and scratch,
 * and 2MB at end for u-boot code and data relocated
 */
#define CONFIG_SYS_MEMTEST_START	(STM32_DDR_BASE + SZ_1M)
#define CONFIG_SYS_MEMTEST_END		(STM32_DDR_BASE + SZ_64M - 2 * SZ_1M)
#define CONFIG_SYS_MEMTEST_SCRATCH	(CONFIG_SYS_MEMTEST_START - 4)

/*MMC SD*/
#define CONFIG_SYS_MMC_MAX_DEVICE	3
#define CONFIG_SUPPORT_EMMC_BOOT

/*****************************************************************************/
#ifdef CONFIG_DISTRO_DEFAULTS
/*****************************************************************************/

/* NAND support */
#define CONFIG_SYS_NAND_ONFI_DETECTION
#define CONFIG_SYS_MAX_NAND_DEVICE	1

/* SPI nand */
#define CONFIG_SYS_MAX_NAND_DEVICE	1

/* Watchdog */
#if !defined(CONFIG_SPL) || !defined(CONFIG_SPL_BUILD)
#ifdef CONFIG_STM32MP_WATCHDOG
#define CONFIG_HW_WATCHDOG
#endif
#endif

/* SPI FLASH support */
#if defined(CONFIG_SPL_BUILD)
#define CONFIG_SPL_SPI_LOAD
#define CONFIG_SYS_SPI_U_BOOT_OFFS	0x80000
#endif

/* FILE SYSTEM */

#if defined(CONFIG_STM32_QSPI) || defined(CONFIG_NAND_STM32_FMC)
/* Dynamic MTD partition support */
#define CONFIG_MTD_PARTITIONS
#define CONFIG_MTD_DEVICE	/* needed for mtdparts commands */
#define CONFIG_SYS_MTDPARTS_RUNTIME
#endif

/* Ethernet need */
#ifdef CONFIG_DWC_ETH_QOS
#define CONFIG_SYS_NONCACHED_MEMORY	(1 * SZ_1M)	/* 1M */
#define CONFIG_SERVERIP			192.168.1.240
#define CONFIG_BOOTP_SERVERIP
#define CONFIG_SYS_AUTOLOAD		"no"
#endif

#ifdef CONFIG_DM_VIDEO
#define CONFIG_SPLASH_SCREEN
#define CONFIG_SPLASH_SCREEN_ALIGN
#define CONFIG_SPLASH_SOURCE
#define CONFIG_VIDEO_BMP_RLE8
#define CONFIG_BMP_16BPP
#define CONFIG_BMP_24BPP
#define CONFIG_BMP_32BPP
#endif

#if !defined(CONFIG_SPL_BUILD)

/* default order is SDCARD (SDMMC 0) / eMMC (SDMMC 1) / NAND /  */
#define BOOT_TARGET_DEVICES(func) \
	func(MMC, mmc, 0) \
	func(MMC, mmc, 1) \
	func(UBIFS, ubifs, 0) \
	func(PXE, pxe, na)

#include <config_distro_bootcmd.h>

#if defined(CONFIG_CMD_UBIFS) && defined(CONFIG_SPLASH_SCREEN)
#undef BOOTENV_SHARED_UBIFS
#define BOOTENV_SHARED_UBIFS \
	"ubifs_boot=" \
		"if test ${boot_device} = nand; then " \
			"env exists bootubivol || " \
				"env set bootubivol boot; " \
			"if ubifsmount ubi${devnum}:${bootubivol}; " \
			"then " \
				"setenv devtype ubi; " \
				"run scan_dev_for_boot; " \
			"fi;" \
		"else " \
			"env exists bootubipart || " \
				"env set bootubipart UBI; " \
			"env exists bootubivol || " \
				"env set bootubivol boot; " \
			"if ubi part ${bootubipart} && " \
				"ubifsmount ubi${devnum}:${bootubivol}; " \
			"then " \
				"setenv devtype ubi; " \
				"run scan_dev_for_boot; " \
			"fi;" \
		"fi\0"
#endif

#define CONFIG_PREBOOT \
	"setenv board_name ${board_name}${housing}; " \
	"echo \"Boot over ${boot_device}${boot_instance}!\"; " \
	"if test ${boot_device} = uart; then " \
		"stm32prog serial ${boot_instance}; " \
	"else "\
		"if test ${boot_device} = usb; then " \
			"stm32prog usb ${boot_instance}; " \
		"fi; "\
	"fi; "

#ifdef CONFIG_STM32MP1_OPTEE
/* with OPTEE: define specific MTD partitions = teeh, teed, teex */
#define STM32MP_MTDPARTS \
	"mtdparts_nor0=256k(fsbl1),256k(fsbl2),2m(ssbl),256k(teeh),256k(teed),256k(teex),-(nor_user)\0" \
	"mtdparts_nand0=2m(fsbl),2m(ssbl),512k(teeh),512k(teed),512k(teex),-(UBI);\0"

#ifdef CONFIG_STM32MP15x_REVA
#define STM32MP_MTDPARTS_REVA \
	"mtdparts_nand0_reva=2m@0x80000(fsbl),2m(ssbl),512k(teeh),512k(teed),512k(teex),-(UBI);\0"
#endif
#else /* CONFIG_STM32MP1_OPTEE */
#define STM32MP_MTDPARTS \
	"mtdparts_nor0=256k(fsbl1),256k(fsbl2),1m(ssbl),64k(env),-(nor_user)\0" \
	"mtdparts_nand0=2m(fsbl),2m(ssbl),-(UBI)\0"

#ifdef CONFIG_STM32MP15x_REVA
#define STM32MP_MTDPARTS_REVA \
	"mtdparts_nand0_reva=2m@0x80000(fsbl),2m(ssbl),-(UBI)\0"
#endif
#endif /* CONFIG_STM32MP1_OPTEE */

#ifndef STM32MP_MTDPARTS_REVA
/* TEMP: to remove */
#define STM32MP_MTDPARTS_REVA
#endif

#define CONFIG_EXTRA_ENV_SETTINGS \
	"stdin=serial\0" \
	"stdout=serial\0" \
	"stderr=serial\0" \
	"scriptaddr=0xC0000000\0" \
	"pxefile_addr_r=0xC0000000\0" \
	"kernel_addr_r=0xC1000000\0" \
	"fdt_addr_r=0xC4000000\0" \
	"ramdisk_addr_r=0xC4100000\0" \
	"fdt_high=0xffffffff\0" \
	"initrd_high=0xffffffff\0" \
	"bootlimit=0\0" \
	"altbootcmd=run bootcmd\0" \
	"usb_pgood_delay=2000\0" \
	"splashpos=m,m\0"  \
	"splashimage=0xC0800000\0"  \
	STM32MP_MTDPARTS \
	STM32MP_MTDPARTS_REVA \
	BOOTENV \
	"boot_net_usb_start=true\0"

#endif /* ifndef CONFIG_SPL_BUILD */
#endif /* ifdef CONFIG_DISTRO_DEFAULTS*/

#endif /* __CONFIG_H */
