SUMMARY = "A basic console image"
LICENSE = "MIT"

inherit core-image
inherit distro_features_check

IMAGE_FEATURES += "\
	package-management \
	ssh-server-openssh \
	"

# This is graphics dependent
IMAGE_FEATURES += "\
	splash \
	hwcodecs \
	"

########################################
##### BASIC PACKAGES ###################
########################################
IMAGE_INSTALL += "\
	packagegroup-core-boot \
	packagegroup-base \
	packagegroup-base-extended \
	${MACHINE_EXTRA_RRECOMMENDS} \
	${CORE_IMAGE_EXTRA_INSTALL} \
	nano \
	openssh-sftp-server \
	mtd-utils \
	u-boot-fw-utils \
	os-release \
	htop \
	"

# Additional diagnostic packages
IMAGE_INSTALL_DIAGNOSTICS += "\
	memtester \
	cpufrequtils \
	libgpiod \
	libiio-tests \
	can-utils \
	i2c-tools \
	spitools \
	evtest \
	\
	mmc-utils \
	mtd-utils-ubifs \
	\
	iperf3 \
	iproute2 \
	\
	libdrm-tests \
	"
IMAGE_INSTALL += "${IMAGE_INSTALL_DIAGNOSTICS}"

# Fix wrong dependency in OpenST:
# If we don't have gcnano-userland-binary nobody builds the recipe 'gcnano-driver-stm32mp'
# In MACHINE_EXTRA_RRECOMMENDS 'kernel-module-galcore' is set when GPU machine feature is
# activated.
# -> So building the image fails because kernel-module-galcore is not available
#    (the linux kernel RPROVIDES all kernel-module-* dependencies by default. But this
#    doesn't help here because somebody must PROVIDE it)
# -> The simplest way is to install 'gcnano-driver-stm32mp' directly
# REMARK: Adding a PROVIDE += "kernel-module-galcore" to the 'gcnano-driver-stm32mp.bb'
#         recipe seems not to help (proofed), because the "kernel-module-*" dependencies
#         are fulfilled by the install of the kernel recipe (!?  this is an expectation!)
#         and therefore after building the linux kernel our recipe 'kernel-module-galcore'
#         isn't build!
# REMARK: gcnano-driver-stm32mp has to be built to get the kernel-module-galcore which have
#         to be installed. So both must be mentionned in IMAGE_INSTALL to be built
#         (gcnano-driver-stm32mp) and to be installed (kernel-module-galcore). The reason
#         for this is that the kernel module is named 'galcore.ko' and the recipe named
#         gcnano-driver-stm32mp. The kernel module package is always named after the *.ko
#         name of the driver! So gcnano-driver-stm32mp is an empty dummy package.
IMAGE_INSTALL += "${@bb.utils.contains('MACHINE_FEATURES', 'gpu', 'gcnano-driver-stm32mp', '', d)} "

# Add boot files to image
# This is dependent on bootscheme.
# Here: extlinux with only one bootfs partition else these packages are included in bootfs image
#IMAGE_INSTALL += "\
#	u-boot-stm32mp-extlinux \
#	kernel-imagebootfs \
#	"

# TODO: Currently only available on imx6
#IMAGE_INSTALL = "production-tool  udev-extraconf"

# Special packages
IMAGE_INSTALL += "\
	${@bb.utils.contains('DISTRO_FEATURES', 'systemd', 'systemd-networkd-configuration', '', d)} \
	${@bb.utils.contains('DISTRO_FEATURES', 'systemd', 'systemd-analyze', '', d)} \
	"

# reserve extra space of 10 MiB in rootfs image
IMAGE_ROOTFS_EXTRA_SPACE ?= "10"

# Any language must be installed
IMAGE_LINGUAS ?= "en-gb"

do_deploy[vardepsexclude] = "DATETIME"
